@@ -17,22 +17,20 @@
 """Command-line interface to the OpenStack APIs"""
 
 import getpass
-import locale
 import logging
 import sys
 import traceback
 
 from cliff import app
 from cliff import command
+from cliff import commandmanager
 from cliff import complete
 from cliff import help
 from oslo_utils import importutils
 from oslo_utils import strutils
-import six
 
 from osc_lib.cli import client_config as cloud_config
 from osc_lib import clientmanager
-from osc_lib.command import commandmanager
 from osc_lib.command import timing
 from osc_lib import exceptions as exc
 from osc_lib.i18n import _
@@ -44,6 +42,7 @@ osprofiler_profiler = importutils.try_import("osprofiler.profiler")
 
 
 DEFAULT_DOMAIN = 'default'
+DEFAULT_INTERFACE = 'public'
 
 
 def prompt_for_password(prompt=None):
@@ -255,10 +254,12 @@ class OpenStackShell(app.App):
             metavar='<interface>',
             dest='interface',
             choices=['admin', 'public', 'internal'],
-            default=utils.env('OS_INTERFACE'),
+            default=utils.env(
+                'OS_INTERFACE',
+                default=DEFAULT_INTERFACE),
             help=_('Select an interface type.'
                    ' Valid interface types: [admin, public, internal].'
-                   ' (Env: OS_INTERFACE)'),
+                   ' default=%s, (Env: OS_INTERFACE)') % DEFAULT_INTERFACE,
         )
         parser.add_argument(
             '--os-service-provider',
@@ -395,7 +396,7 @@ class OpenStackShell(app.App):
         # Parent __init__ parses argv into self.options
         super(OpenStackShell, self).initialize_app(argv)
         self.log.info("START with options: %s",
-                      strutils.mask_password(self.command_options))
+                      strutils.mask_password(" ".join(self.command_options)))
         self.log.debug("options: %s",
                        strutils.mask_password(self.options))
 
@@ -403,8 +404,6 @@ class OpenStackShell(app.App):
         self._final_defaults()
 
         # Do configuration file handling
-        # Ignore the default value of interface. Only if it is set later
-        # will it be used.
         try:
             self.cloud_config = cloud_config.OSC_Config(
                 pw_func=prompt_for_password,
@@ -489,7 +488,8 @@ class OpenStackShell(app.App):
                 # let the command decide whether we need a scoped token
                 self.client_manager.validate_scope()
             # Trigger the Identity client to initialize
-            self.client_manager.auth_ref
+            self.client_manager.session.auth.auth_ref = \
+                self.client_manager.auth_ref
         return
 
     def clean_up(self, cmd, result, err):
@@ -521,12 +521,6 @@ class OpenStackShell(app.App):
 def main(argv=None):
     if argv is None:
         argv = sys.argv[1:]
-        if six.PY2:
-            # Emulate Py3, decode argv into Unicode based on locale so that
-            # commands always see arguments as text instead of binary data
-            encoding = locale.getpreferredencoding()
-            if encoding:
-                argv = map(lambda arg: arg.decode(encoding), argv)
     return OpenStackShell().run(argv)
 
 
